@@ -24,63 +24,16 @@
 #define CHARACTERCOLOR_H
 
 // Qt
-#include <QtGui/QColor>
+#include <QColor>
 
-namespace Konsole
-{
+namespace Konsole {
 /**
  * An entry in a terminal display's color palette.
  *
  * A color palette is an array of 16 ColorEntry instances which map
  * system color indexes (from 0 to 15) into actual colors.
  */
-class ColorEntry
-{
-public:
-    /**
-     * Constructs a new color palette entry.
-     *
-     * @param c The color value for this entry.
-     */
-    explicit ColorEntry(QColor c)
-        : color(c) {}
-
-    /**
-     * Constructs a new color palette entry using black color.
-     */
-    ColorEntry() : color(QColor(0x00, 0x00, 0x00)) {}
-
-    /**
-     * Sets the color of this color to those of @p rhs.
-     */
-    void operator=(const ColorEntry& rhs) {
-        color = rhs.color;
-    }
-
-    /** The color value of this entry for display. */
-    QColor color;
-
-    /**
-     * Compares two color entries and returns true if they represent the same
-     * color.
-     */
-    friend bool operator == (const ColorEntry& a, const ColorEntry& b);
-    /**
-     * Compares two color entries and returns true if they represent different
-     * color.
-     */
-    friend bool operator != (const ColorEntry& a, const ColorEntry& b);
-};
-
-inline bool operator == (const ColorEntry& a, const ColorEntry& b)
-{
-    return  a.color == b.color;
-}
-
-inline bool operator != (const ColorEntry& a, const ColorEntry& b)
-{
-    return !operator==(a, b);
-}
+typedef QColor ColorEntry;
 
 // Attributed Character Representations ///////////////////////////////
 
@@ -126,12 +79,13 @@ class CharacterColor
 
 public:
     /** Constructs a new CharacterColor whose color and color space are undefined. */
-    CharacterColor()
-        : _colorSpace(COLOR_SPACE_UNDEFINED),
-          _u(0),
-          _v(0),
-          _w(0)
-    {}
+    CharacterColor() :
+        _colorSpace(COLOR_SPACE_UNDEFINED),
+        _u(0),
+        _v(0),
+        _w(0)
+    {
+    }
 
     /**
      * Constructs a new CharacterColor using the specified @p colorSpace and with
@@ -143,11 +97,12 @@ public:
      *
      * TODO : Add documentation about available color spaces.
      */
-    CharacterColor(quint8 colorSpace, int co)
-        : _colorSpace(colorSpace),
-          _u(0),
-          _v(0),
-          _w(0) {
+    CharacterColor(quint8 colorSpace, int co) :
+        _colorSpace(colorSpace),
+        _u(0),
+        _v(0),
+        _w(0)
+    {
         switch (colorSpace) {
         case COLOR_SPACE_DEFAULT:
             _u = co & 1;
@@ -172,7 +127,8 @@ public:
     /**
      * Returns true if this character color entry is valid.
      */
-    bool isValid() const {
+    bool isValid() const
+    {
         return _colorSpace != COLOR_SPACE_UNDEFINED;
     }
 
@@ -198,18 +154,18 @@ public:
      * The @p palette is only used if this color is one of the 16 system colors, otherwise
      * it is ignored.
      */
-    QColor color(const ColorEntry* palette) const;
+    QColor color(const ColorEntry *palette) const;
 
     /**
      * Compares two colors and returns true if they represent the same color value and
      * use the same color space.
      */
-    friend bool operator == (const CharacterColor& a, const CharacterColor& b);
+    friend bool operator ==(const CharacterColor &a, const CharacterColor &b);
     /**
      * Compares two colors and returns true if they represent different color values
      * or use different color spaces.
      */
-    friend bool operator != (const CharacterColor& a, const CharacterColor& b);
+    friend bool operator !=(const CharacterColor &a, const CharacterColor &b);
 
 private:
     quint8 _colorSpace;
@@ -220,27 +176,28 @@ private:
     quint8 _w;
 };
 
-inline bool operator == (const CharacterColor& a, const CharacterColor& b)
+inline bool operator ==(const CharacterColor &a, const CharacterColor &b)
 {
-    return     a._colorSpace == b._colorSpace &&
-               a._u == b._u &&
-               a._v == b._v &&
-               a._w == b._w;
+    return a._colorSpace == b._colorSpace
+           && a._u == b._u
+           && a._v == b._v
+           && a._w == b._w;
 }
-inline bool operator != (const CharacterColor& a, const CharacterColor& b)
+
+inline bool operator !=(const CharacterColor &a, const CharacterColor &b)
 {
     return !operator==(a, b);
 }
 
-inline const QColor color256(quint8 u, const ColorEntry* base)
+inline const QColor color256(quint8 u, const ColorEntry *base)
 {
     //   0.. 16: system colors
     if (u < 8) {
-        return base[u + 2].color;
+        return base[u + 2];
     }
     u -= 8;
     if (u < 8) {
-        return base[u + 2 + BASE_COLORS].color;
+        return base[u + 2 + BASE_COLORS];
     }
     u -= 8;
 
@@ -258,13 +215,13 @@ inline const QColor color256(quint8 u, const ColorEntry* base)
     return QColor(gray, gray, gray);
 }
 
-inline QColor CharacterColor::color(const ColorEntry* base) const
+inline QColor CharacterColor::color(const ColorEntry *base) const
 {
     switch (_colorSpace) {
     case COLOR_SPACE_DEFAULT:
-        return base[_u + 0 + (_v * BASE_COLORS)].color;
+        return base[_u + 0 + (_v * BASE_COLORS)];
     case COLOR_SPACE_SYSTEM:
-        return base[_u + 2 + (_v * BASE_COLORS)].color;
+        return base[_u + 2 + (_v * BASE_COLORS)];
     case COLOR_SPACE_256:
         return color256(_u, base);
     case COLOR_SPACE_RGB:
@@ -291,8 +248,6 @@ inline void CharacterColor::setFaint()
         _v = 2;
     }
 }
-
 }
 
 #endif // CHARACTERCOLOR_H
-
