@@ -41,7 +41,7 @@ using namespace Konsole;
 
 KeyboardTranslatorWriter::KeyboardTranslatorWriter(QIODevice *destination) :
     _destination(destination),
-    _writer(0)
+    _writer(nullptr)
 {
     Q_ASSERT(destination && destination->isWritable());
 
